@@ -1,12 +1,12 @@
 #!/bin/sh -e
 
 VERSION=$2
-TAR=../tomcat6_$VERSION.orig.tar.xz
-DIR=tomcat6-$VERSION
+TAR=../tomcat7_$VERSION.orig.tar.xz
+DIR=tomcat7-$VERSION
 TAG=$(echo TOMCAT_$VERSION | sed -e 's/\./_/g')
 
-svn export http://svn.apache.org/repos/asf/tomcat/tc6.0.x/tags/$TAG $DIR
-tar -c -J -f $TAR --exclude 'standard.jar' --exclude 'jstl.jar' $DIR
+svn export http://svn.apache.org/repos/asf/tomcat/tc7.0.x/tags/$TAG $DIR
+XZ_OPT=--best tar -c -J -f $TAR --exclude 'taglibs-standard-*.jar' $DIR
 rm -rf $DIR ../$TAG
 
 # move to directory 'tarballs'
